==> ckeditor_4.4.4+dfsg1.orig.tar.xz: ckeditor-dev-4.4.4/plugins/forms/lang/mn.js <==
﻿/*
Copyright (c) 2003-2014, CKSource - Frederico Knabben. All rights reserved.
For licensing, see LICENSE.md or http://ckeditor.com/license
*/
CKEDITOR.plugins.setLang( 'forms', 'mn', {
	button: {
		title: 'Товчны шинж чанар',
		text: 'Тэкст (Утга)',
		type: 'Төрөл',
		typeBtn: 'Товч',
		typeSbm: 'Submit',
		typeRst: 'Болих'
	},
	checkboxAndRadio: {
		checkboxTitle: 'Чекбоксны шинж чанар',
		radioTitle: 'Радио товчны шинж чанар',
		value: 'Утга',
		selected: 'Сонгогдсон'
	},
	form: {
		title: 'Форм шинж чанар',
		menu: 'Форм шинж чанар',
		action: 'Үйлдэл',
		method: 'Арга',
		encoding: 'Encoding'
	},
	hidden: {
		title: 'Нууц талбарын шинж чанар',
		name: 'Нэр',
		value: 'Утга'
	},
	select: {
		title: 'Согогч талбарын шинж чанар',
		selectInfo: 'Мэдээлэл',
		opAvail: 'Идвэхтэй сонголт',
		value: 'Утга',
		size: 'Хэмжээ',
		lines: 'Мөр',
		chkMulti: 'Олон зүйл зэрэг сонгохыг зөвшөөрөх',
		opText: 'Тэкст',
		opValue: 'Утга',
		btnAdd: 'Нэмэх',
		btnModify: 'Өөрчлөх',
		btnUp: 'Дээш',
		btnDown: 'Доош',
		btnSetValue: 'Сонгогдсан утга оноох',
		btnDelete: 'Устгах'
	},
	textarea: {
		title: 'Текст орчны шинж чанар',
		cols: 'Багана',
		rows: 'Мөр'
	},
	textfield: {
		title: 'Текст талбарын шинж чанар',
		name: 'Нэр',
		value: 'Утга',
		charWidth: 'Тэмдэгтын өргөн',
		maxChars: 'Хамгийн их тэмдэгт',
		type: 'Төрөл',
		typeText: 'Текст',
		typePass: 'Нууц үг',
		typeEmail: 'Email', // MISSING
		typeSearch: 'Search', // MISSING
		typeTel: 'Telephone Number', // MISSING
		typeUrl: 'цахим хуудасны хаяг (URL)'
	}
} );

==> ckeditor_4.5.7+dfsg.orig.tar.xz: ckeditor-dev-4.5.7/plugins/forms/lang/mn.js <==
/*
Copyright (c) 2003-2016, CKSource - Frederico Knabben. All rights reserved.
For licensing, see LICENSE.md or http://ckeditor.com/license
*/
CKEDITOR.plugins.setLang( 'forms', 'mn', {
	button: {
		title: 'Товчны шинж чанар',
		text: 'Тэкст (Утга)',
		type: 'Төрөл',
		typeBtn: 'Товч',
		typeSbm: 'Submit',
		typeRst: 'Болих'
	},
	checkboxAndRadio: {
		checkboxTitle: 'Чекбоксны шинж чанар',
		radioTitle: 'Радио товчны шинж чанар',
		value: 'Утга',
		selected: 'Сонгогдсон',
		required: 'Required' // MISSING
	},
	form: {
		title: 'Форм шинж чанар',
		menu: 'Форм шинж чанар',
		action: 'Үйлдэл',
		method: 'Арга',
		encoding: 'Encoding'
	},
	hidden: {
		title: 'Нууц талбарын шинж чанар',
		name: 'Нэр',
		value: 'Утга'
	},
	select: {
		title: 'Согогч талбарын шинж чанар',
		selectInfo: 'Мэдээлэл',
		opAvail: 'Идвэхтэй сонголт',
		value: 'Утга',
		size: 'Хэмжээ',
		lines: 'Мөр',
		chkMulti: 'Олон зүйл зэрэг сонгохыг зөвшөөрөх',
		required: 'Required', // MISSING
		opText: 'Тэкст',
		opValue: 'Утга',
		btnAdd: 'Нэмэх',
		btnModify: 'Өөрчлөх',
		btnUp: 'Дээш',
		btnDown: 'Доош',
		btnSetValue: 'Сонгогдсан утга оноох',
		btnDelete: 'Устгах'
	},
	textarea: {
		title: 'Текст орчны шинж чанар',
		cols: 'Багана',
		rows: 'Мөр'
	},
	textfield: {
		title: 'Текст талбарын шинж чанар',
		name: 'Нэр',
		value: 'Утга',
		charWidth: 'Тэмдэгтын өргөн',
		maxChars: 'Хамгийн их тэмдэгт',
		required: 'Required', // MISSING
		type: 'Төрөл',
		typeText: 'Текст',
		typePass: 'Нууц үг',
		typeEmail: 'Email', // MISSING
		typeSearch: 'Search', // MISSING
		typeTel: 'Telephone Number', // MISSING
		typeUrl: 'цахим хуудасны хаяг (URL)'
	}
} );
